from dataclasses import dataclass
import enum
import logging
from typing import Optional

import numpy as np

from hpcflow.sdk.core.zarr_io import ZarrEncodable

logger = logging.getLogger(__name__)


@dataclass
class SubParameter:
    pass


@dataclass
class OrientationFormat(enum.Enum):

    # i.e. InputValue(parameter=Parameter(typ='orientations'), path=('ori_format',), value=...)

    QUATERNION = 1
    EULER = 2


@dataclass
class Orientations(ZarrEncodable):

    # i.e. InputValue(parameter=Parameter(typ='orientations'), value=...)
    _typ = "orientations"

    # _sub_parameters = (
    #     SubParameter(path=("ori_format",), is_enum=True, class_obj=OrientationFormat),
    # )

    data: np.ndarray
    ori_format: Optional[OrientationFormat] = None

    def __post_init__(self):
        pass
        # if not isinstance(self.ori_format, OrientationFormat):
        #     self.ori_format = getattr(OrientationFormat, self.ori_format.upper())

    @classmethod
    def from_JSON_like(cls, data, ori_format):
        """For custom initialisation via YAML or JSON."""
        return cls(data=np.asarray(data), ori_format=ori_format)

    # def to_json_like(self, dct=None, shared_data=None, exclude=None, _depth=0):
    #     return



import logging
import click

from matflow import MatFlow
import matflow.api

logger = logging.getLogger(__name__)


@MatFlow.CLI.group()
def parameter():  # matflow-only command group
    pass


@parameter.command("search")  # matflow-only command
def parameter_search():
    matflow.api.parameter_search()


if __name__ == "__main__":
    MatFlow.CLI()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['matflow', 'matflow.data']

package_data = \
{'': ['*']}

install_requires = \
['hpcflow-new2>=0.2.0a7,<0.3.0']

extras_require = \
{'pyinstaller': ['pyinstaller>=5.5,<6.0']}

entry_points = \
{'console_scripts': ['matflow = matflow.cli:MatFlow.CLI'],
 'pyinstaller40': ['hook-dirs = pyinstaller.__init__:get_hook_dirs']}

setup_kwargs = {
    'name': 'matflow-new',
    'version': '0.3.0a5',
    'description': 'Computational workflows for materials science',
    'long_description': '<img src="https://docs.matflow.io/stable/_static/images/logo-90dpi.png" width="250" alt="MatFlow logo"/>\n\n**Design, run, and share computational materials science workflows**\n\nDocumentation: [https://matflow.io/docs](https://matflow.io/docs)\n\n## Acknowledgements\n\n\nMatFlow was developed using funding from the [LightForm](https://lightform.org.uk/) EPSRC programme grant ([EP/R001715/1](https://gow.epsrc.ukri.org/NGBOViewGrant.aspx?GrantRef=EP/R001715/1))\n\n<img src="https://lightform-group.github.io/wiki/assets/images/site/lightform-logo.png" width="150"/>\n',
    'author': 'aplowman',
    'author_email': 'adam.plowman@manchester.ac.uk',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<3.11',
}


setup(**setup_kwargs)
